local releases = {
	{
		id = "662c356ad984b2791d1fc4a9296c6302",
		name = "Painting: The Stitches",
		type = "esoPlusFreebie",
		startDate = 1724940000,
		endDate = 1727964000,
	},
	{
		id = "3cd5b4e0a29547f55b4127cf4b4ff88b",
		name = "Painting: Oathsworn Pit",
		type = "esoPlusFreebie",
		startDate = 1727964000,
		endDate = 1732114800,
	},
	{
		id = "4fcf71b27ceb27c9ba47b522656d4ba4",
		name = "Scourge Harvester Style",
		type = "style",
		startDate = 1728309600,
		endDate = 1728568800,
		source = "The matching mask page will have a small chance to drop from Varaine or Allene Pellingare from Veteran Wayrest Sewers II.\
\
The matching shoulder page can be purchased from Maj al-Ragath for 50 Undaunted keys, or has a chance of dropping from Maj's Mystery Coffer for 1 key.\
\
Having the achievement \"Pellingare Ghoul Slayer\" increases the drop chances of both items.",
	},
	{
		id = "1543113cdd1156173a72cdb9761ddd4b",
		name = "Crowborne Hunter Style",
		type = "style",
		startDate = 1729173600,
		endDate = 1729519200,
		source = "Matching armor pages will have a small chance to drop from Plunder Skulls.\
\
Bound versions of the armor pages can be purchased from the Impresario for 5 Event Tickets each during the Witches Festival event.",
	},
}

local provider = LibNotification:CreateProvider()
local declined

local function UpdateNotifications()
	local function OnDecline(data)
		declined[data.id] = true
		UpdateNotifications()
	end

	local currentTimeStamp = GetTimeStamp()
	provider.notifications = {}

	for _, v in ipairs(releases) do
		if
			(v.type ~= "esoPlusFreebie" or IsESOPlusSubscriber()) and
			declined[v.id] == nil and
			GetDiffBetweenTimeStamps(v.startDate, currentTimeStamp) <= 0 and
			(v.endDate == nil or GetDiffBetweenTimeStamps(currentTimeStamp, v.endDate) < 0)
		then
			table.insert(
				provider.notifications,
				{
					id = v.id,
					dataType = NOTIFICATIONS_ALERT_DATA,
					secsSinceRequest = ZO_NormalizeSecondsSince(0),
					note = v.type == "esoPlusFreebie" and "Free in Crown Store with ESO+" or v.source,
					message = v.name,
					heading = "Content Releases",
					shortDisplayText = "Content Releases",
					texture = v.type == "esoPlusFreebie" and "/esoui/art/treeicons/gamepad/tutorial_idexicon_esoplus.dds" or "/esoui/art/dailyloginrewards/dailyloginrewards_claimed_stamp.dds",
					keyboardDeclineCallback = OnDecline,
					gamepadDeclineCallback = OnDecline
				}
			)
		end
	end

	provider:UpdateNotifications()
end

SLASH_COMMANDS["/releases"] = function()
	local currentTimeStamp = GetTimeStamp()

	CHAT_ROUTER:AddSystemMessage("Content Releases")

	for _, v in ipairs(releases) do
		if
			(v.type ~= "esoPlusFreebie" or IsESOPlusSubscriber()) and
			(v.endDate == nil or GetDiffBetweenTimeStamps(currentTimeStamp, v.endDate) < 0)
		then
			if v.source then
				local achievementName = string.match(v.source, "achievement \"(.+)\"")

				if achievementName then
					for achievementId = 1, 9999 do
						if achievementName == GetAchievementName(achievementId) then
							v.source = string.gsub(v.source, string.gsub(achievementName, "-", "%%-"), GetAchievementLink(achievementId))
							break
						end
					end
				end
			end

			CHAT_ROUTER:AddSystemMessage(
				zo_strformat(
					v.endDate == nil and "<<1>> [<<3>>]\n<<2>>" or "<<1>> [<<3>> to <<4>>]\n<<2>>",
					v.name,
					v.type == "esoPlusFreebie" and "Free in Crown Store with ESO+" or v.source,
					GetDateStringFromTimestamp(v.startDate),
					GetDateStringFromTimestamp(v.endDate)
				)
			)
		end
	end
end

EVENT_MANAGER:RegisterForEvent(
	"ReleaseTracker",
	EVENT_ADD_ON_LOADED,
	function(_, addOnName)
		if "ReleaseTracker" ~= addOnName then return end

		declined = ZO_SavedVars:NewAccountWide("ReleaseTracker", 1, nil, {})

		UpdateNotifications()

		local currentTimeStamp = GetTimeStamp()

		for _, v in ipairs(releases) do
			local timeUntilStart = GetDiffBetweenTimeStamps(v.startDate, currentTimeStamp)

			if timeUntilStart > 0 then
				EVENT_MANAGER:RegisterForUpdate(
					"ReleaseCheck" .. v.startDate,
					timeUntilStart * 1000,
					function()
						EVENT_MANAGER:UnregisterForUpdate("ReleaseCheck" .. v.startDate)
						UpdateNotifications()
					end
				)
			end
		end
	end
)